@@ -4,13 +4,13 @@ use strict;
 
 # ABSTRACT: Mock the world with one object
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 our $AUTOLOAD;
 
 use overload '""' => '_stringify';
 
-use List::Util qw(any);
+use List::Util 1.33 qw(any);
 use Scalar::Util qw(blessed);
 
 sub new {
@@ -98,7 +98,7 @@ Test::Mock::One - Mock the world with one object
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
